/***********************************************************************************************\
 * This is the main header file for the data transfer for Linux, called iqdata.h 	*
 *                                                                                		*
 * Copyright           :        anritsu corporation            				*
 * Date written        :        September 13, 2017           				*
 * Modification Notes  : -----------------------------------------------------------	*
 *           								                  	*
 *                                                 						*
 *                    										*
 *                                                                                		*
 \**********************************************************************************************/
#pragma once
#include <stdint.h>

/********************************************************************************************
  Prototype    : bool iqdata_open(void);
  Description  : This function initializes API to prepare for transferring IQ data.
  Parameters   : None
  Return Value : Returns a boolean, 
		  if success,true;else false.
 *******************************************************************************************/
extern bool iqdata_open(void);

/********************************************************************************************
  Prototype    : bool iqdata_close(void);
  Description  : This function closes API to finish transferig IQ data.
  Parameters   : None
  Return Value : Returns a boolean, 
		  if success,true;else false.
 *******************************************************************************************/
extern bool iqdata_close(void);

/********************************************************************************************
  Prototype    : bool iqdata_readplus(void* pbuffer,
				 	int* offset,
				 	uint32_t datasize,
					uint64_t read_offset,
					bool output = false,
					char* path = (char*)"",
					char* filename = (char*)"");

  Description  : This function reads IQ data from the instrument.
		   It can save the data to the local PC.
  Parameters   : 
		   void* pbuffer 		: The memory pointer for reading IQ data
		   int* offset   		: The memory pointer offset for reading IQ data
	          uint32_t datasize		: The data size in bytes
                 uint64_t read_offset	: The data shift of DMA reading in bytes
	          bool output = false	: The switch for saving IQ data, default value is 'false'
		   char* path = (char*)""	: The path of saved IQ data, default value is '""' (Maximum length <= 512 bytes)
		   char* filename = (char*)"" : The filename of saved IQ data, default value is '""' (Maximum length <= 64 bytes)

  Return Value : Returns a boolean, 
		   if success,true;else false.
 *******************************************************************************************/
extern bool iqdata_readplus(void* pbuffer,
				 	int* offset,
				 	uint32_t datasize,
					uint64_t read_offset,
					bool output = false,
					char* path = (char*)"",
					char* filename = (char*)"");

/********************************************************************************************
  Prototype    : bool iqdata_read(void* pbuffer,
				 	int* offset,
				 	uint32_t datasize,
					uint64_t read_offset);

  Description  : This function reads IQ data from the instrument.
		   It can not save the data to the local PC.
  Parameters   : 
		   void* pbuffer 		: The memory pointer for reading IQ data
		   int* offset   		: The memory pointer offset for reading IQ data
	          uint32_t datasize		: The data size in bytes
                 uint64_t read_offset	: The data shift of DMA reading in bytes

  Return Value : Returns a boolean, 
		   if success,true;else false.
 *******************************************************************************************/
extern bool iqdata_read(	void* pbuffer,
		    	    	int* offset,
		    	    	uint32_t datasize,
		           	uint64_t read_offset);

/********************************************************************************************
  Prototype    : uint64_t iqdata_get_data_size(void);
  Description  : This function gets size of IQ data.
  Parameters   : None
  Return Value : Returns size of IQ data in bytes. 
 *******************************************************************************************/
extern uint64_t iqdata_get_data_size(void);

/********************************************************************************************
  Prototype    : char* iqdata_get_fail_msg(void);
  Description  : This function gets last information if run failed.
  Parameters   : None
  Return Value : Returns a string, shows the error message of last run failed.
 *******************************************************************************************/
extern char* iqdata_get_fail_msg(void);

/********************************************************************************************
  Prototype    : bool iqdata_get_level_overflow(void);
  Description  : This function gets sign of level overflow whether it occurred or not.
  Parameters   : None
  Return Value : Returns a boolean. 
		   if level overflow occurred,true;else false.
 *******************************************************************************************/
extern bool iqdata_get_level_overflow(void);

/********************************************************************************************
  Prototype    : char* iqdata_get_version(void);
  Description  : This function gets version information of API.
  Parameters   : None
  Return Value : Returns a string, shows the version information.
 *******************************************************************************************/
extern char* iqdata_get_version(void);


